%define major		4
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

Name:		hdhomerun
Version:	20221205
Release:	%mkrel 1
Summary:	Silicon Dust HDHomeRun configuration utility
Group:		System/Configuration
License:	LGPLv2+ and GPLv3
URL:		https://www.silicondust.com/
Source0:	https://download.silicondust.com/hdhomerun/lib%{name}_%{version}.tgz
Source1:	https://download.silicondust.com/hdhomerun/hdhomerun_config_gui_%{version}.tgz
Source2:	hdhomerun_config_gui.desktop
Patch0:		hdhomerun-20221205-add-soname.patch
# From debian:
Patch1:		hdhomerun-20220311-upstream-changelog.patch
BuildRequires:	gcc
BuildRequires:	gcc-c++
BuildRequires:	desktop-file-utils
BuildRequires:	libicns-utils
BuildRequires:	pkgconfig(gtk+-2.0)

%description
The configuration and firmware upgrade utility for Silicon Dust's
networked HDTV dual-tuner HDHomeRun device.

#------------------------------------------------

%package -n	%{libname}
Summary:	Silicon Dust HDHomeRun configuration utility
Group:		System/Libraries

%description -n	%{libname}
The configuration and firmware upgrade utility for Silicon Dust's
networked HDTV dual-tuner HDHomeRun device.

#------------------------------------------------

%package -n	%{develname}
Summary:	Development package for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
Header files for development with %{name}.

#------------------------------------------------

%prep
%setup -q -c -a 1
%autopatch -p1

# Convert files to utf8
for f in libhdhomerun/*; do
  /usr/bin/iconv -f iso-8859-1 -t utf-8 --output $f.new $f && mv $f.new $f
done

%build
cd hdhomerun_config_gui
%configure
%make_build

cd ..
cat << __EOF__ > README.firmware
The HDHomeRun Firmwares are not redistributable, but the latest versions of
both the US ATSC and European DVB-T firmwares can always be obtained from
the Silicon Dust web site:

https://www.silicondust.com/support/linux/

__EOF__

pushd hdhomerun_config_gui/OSX
icns2png -x hdhr.icns
popd

%install
%make_install -C hdhomerun_config_gui

mkdir -p %{buildroot}%{_includedir}/%{name}
install -m 0644 libhdhomerun/*.h %{buildroot}%{_includedir}/%{name}/

desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE2}

for size in 16x16 32x32 128x128 256x256 512x512
do
    mkdir -p %{buildroot}%{_iconsdir}/hicolor/${size}/apps
    install -m 0644 hdhomerun_config_gui/OSX/hdhr_${size}x32.png %{buildroot}%{_iconsdir}/hicolor/${size}/apps/hdhr.png
done

%files
%doc libhdhomerun/README.md hdhomerun_config_gui/AUTHORS hdhomerun_config_gui/README README.firmware
%license libhdhomerun/LICENSE hdhomerun_config_gui/COPYING
# lib and cli are LGPLv2+
%{_bindir}/%{name}_config
# gui is GPLv3
%{_bindir}/%{name}_config_gui
%{_datadir}/applications/%{name}_config_gui.desktop
%{_iconsdir}/hicolor/*/apps/hdhr.png

%files -n %{libname}
%doc libhdhomerun/LICENSE
# lib and cli are LGPLv2+
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{develname}
%doc libhdhomerun/README.md
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so


%changelog
* Fri Jan 20 2023 daviddavid <daviddavid> 20221205-1.mga9
+ Revision: 1934584
- new version: 20221205

* Sun Sep 04 2022 papoteur <papoteur> 20220822-1.mga9
+ Revision: 1883756
- new 20220822

* Tue Mar 29 2022 umeabot <umeabot> 20210224-2.mga9
+ Revision: 1831925
- Mageia 9 Mass Rebuild

* Fri Feb 26 2021 daviddavid <daviddavid> 20210224-1.mga9
+ Revision: 1691949
- new version: 20210224

* Wed Oct 21 2020 daviddavid <daviddavid> 20200907-1.mga8
+ Revision: 1637512
- new version: 20200907

* Thu May 28 2020 daviddavid <daviddavid> 20200521-1.mga8
+ Revision: 1588425
- new version: 20200521

* Thu Feb 27 2020 daviddavid <daviddavid> 20200225-1.mga8
+ Revision: 1550958
- new version: 20200225

* Sat Feb 15 2020 umeabot <umeabot> 20190621-2.mga8
+ Revision: 1526816
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Jun 30 2019 daviddavid <daviddavid> 20190621-1.mga8
+ Revision: 1416358
- new version: 20190621

* Mon Jan 21 2019 daviddavid <daviddavid> 20180817-1.mga7
+ Revision: 1358696
- initial package hdhomerun (needed for mythtv)

